Tsffs_alloc

Function Tsffs_alloc 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn Tsffs_alloc( cls: *mut ConfClass, ) -> *mut ConfObject
FFI wrapper

Safety

This function is unsafe because it may dereference a raw pointer. It is up to the implementation of the class’s alloc method to ensure that the pointer is valid.