Tsffs_deinit

Function Tsffs_deinit 

#[unsafe(no_mangle)]
pub extern "C" fn Tsffs_deinit(obj: *mut ConfObject)
FFI wrapper

Safety

This function is unsafe because it may dereference a raw pointer. It is up to the implementation of the class’s deinit method to ensure that the pointer is valid.