#[unsafe(no_mangle)]pub extern "C" fn Tsffs_finalize(obj: *mut ConfObject)Expand description
FFI wrapper
Safety
This function is unsafe because it may dereference a raw pointer. It is up to the
implementation of the class’s finalize method to ensure that the pointer is valid.