Tsffs_init

Function Tsffs_init 

#[unsafe(no_mangle)]
pub extern "C" fn Tsffs_init(obj: *mut ConfObject) -> *mut c_void
FFI wrapper

Safety

This function is unsafe because it may dereference a raw pointer. It is up to the implementation of the class’s init method to ensure that the pointer is valid.