Tsffs_objects_finalized

Function Tsffs_objects_finalized 

#[unsafe(no_mangle)]
pub extern "C" fn Tsffs_objects_finalized(obj: *mut ConfObject)
FFI wrapper

Safety

This function is unsafe because it may dereference a raw pointer. It is up to the implementation of the class’s objects_finalized method to ensure that the pointer is valid.